==> spip_4.0.4.orig.tar.xz: plugins-dist/dump/lang/dump_hu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=hu
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_restaurer_base' => 'Adatbázis resztaurálása',

	// I
	'info_restauration_sauvegarde' => 'A @archive@ nevű mentés resztaurálása', # MODIF
	'info_sauvegarde' => 'Mentés',
	'info_sauvegarde_reussi_02' => 'Az adatbázis mentve lett a @archive@ nevű mappába. Lehet',
	'info_sauvegarde_reussi_03' => 'visszatérni',
	'info_sauvegarde_reussi_04' => 'honlapja üzemeltetéséhez.',

	// T
	'texte_admin_tech_01' => 'Ez az opció lehetővé teszi az adatbázis tartalmának a mentését egy fájlban, ami az @dossier@ mappában található. Ne felejtse el megmenteni az @img@ mappa teljes tartalmát, ami a cikkekben és a rovatokban használt dokumentumokat, illetve képeket tartalmazza.',
	'texte_admin_tech_02' => 'Vigyázat: ezt a mentést lehet resztaurálni CSAK egy azonos verziójű SPIP honlapon. Tehát nem szabad  « üríteni az adatbázis » abban a reményben, hogy újratelepítheti a mentést egy verziói fejlesztés után... Érdeklődjön <a href="@spipnet@">az SPIP dokumentációja (Fr)</a>.', # MODIF
	'texte_restaurer_base' => 'Egy megmentett adatbázis tartalmának resztaurálása',
	'texte_restaurer_sauvegarde' => 'Ez az opció lehetővé teszi egy már megmentett adatbázis resztaurálását.
  Azért a mentést tartalmazó fájlt kell helyezni a @dossier@ mappába.
  Legyen óvatos ezzel a lehetőséggel : <b>a módosítások, esetleges vesztések visszavonhatatlanok.</b>', # MODIF
	'texte_sauvegarde' => 'Az adatbázis tartalmának mentése',
	'texte_sauvegarde_base' => 'Adatbázis mentése'
);

==> spip_4.4.11+dfsg.orig.tar.xz: plugins-dist/dump/lang/dump_hu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=hu
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_restaurer_base' => 'Adatbázis resztaurálása',

	// I
	'info_restauration_sauvegarde' => 'A @archive@ nevű mentés resztaurálása', # MODIF
	'info_sauvegarde' => 'Mentés',
	'info_sauvegarde_reussi_02' => 'Az adatbázis mentve lett a @archive@ nevű mappába. Lehet',
	'info_sauvegarde_reussi_03' => 'visszatérni',
	'info_sauvegarde_reussi_04' => 'honlapja üzemeltetéséhez.',

	// T
	'texte_admin_tech_01' => 'Ez az opció lehetővé teszi az adatbázis tartalmának a mentését egy fájlban, ami az @dossier@ mappában található. Ne felejtse el megmenteni az @img@ mappa teljes tartalmát, ami a cikkekben és a rovatokban használt dokumentumokat, illetve képeket tartalmazza.',
	'texte_admin_tech_02' => 'Vigyázat: ezt a mentést lehet resztaurálni CSAK egy azonos verziójű SPIP honlapon. Tehát nem szabad  « üríteni az adatbázis » abban a reményben, hogy újratelepítheti a mentést egy verziói fejlesztés után... Érdeklődjön <a href="@spipnet@">az SPIP dokumentációja (Fr)</a>.', # MODIF
	'texte_restaurer_base' => 'Egy megmentett adatbázis tartalmának resztaurálása',
	'texte_restaurer_sauvegarde' => 'Ez az opció lehetővé teszi egy már megmentett adatbázis resztaurálását.
  Azért a mentést tartalmazó fájlt kell helyezni a @dossier@ mappába.
  Legyen óvatos ezzel a lehetőséggel : <b>a módosítások, esetleges vesztések visszavonhatatlanok.</b>', # MODIF
	'texte_sauvegarde' => 'Az adatbázis tartalmának mentése',
	'texte_sauvegarde_base' => 'Adatbázis mentése',
];
